@@ -1,7 +1,7 @@
 package LINE::Bot::API;
 use strict;
 use warnings;
-our $VERSION = '1.05';
+our $VERSION = '1.06';
 
 use JSON::XS;
 use URI;
@@ -221,10 +221,10 @@ Send reply messages to a user, room or group.
         }
     }
 
-You can get a C<reply_token> from a L<webhook event object|https://developers.line.me/en/reference/messaging-api/#webhook-event-objects>.
+You can get a C<reply_token> from a L<webhook event object|https://developers.line.biz/en/reference/messaging-api/#webhook-event-objects>.
 See the documentation for the C<parse_events_from_json($json)> method.
 
-See also the API reference of this method: L<https://developers.line.me/en/reference/messaging-api/#send-reply-message>
+See also the API reference of this method: L<https://developers.line.biz/en/reference/messaging-api/#send-reply-message>
 
 =head2 push_message($user_id|$room_id|$group_id, [ $message, ... ])
 
@@ -234,10 +234,10 @@ Send push messages to a user, room or group.
     $messages->add_text( text => 'Example push text' );
     $bot->push_message($user_id, $messages->build);
 
-You can get a C<user_id>, C<room_id> or C<group_id> from a L<webhook event object|https://developers.line.me/en/reference/messaging-api/#webhook-event-objects>
+You can get a C<user_id>, C<room_id> or C<group_id> from a L<webhook event object|https://developers.line.biz/en/reference/messaging-api/#webhook-event-objects>
 See the documentation for the C<parse_events_from_json($json)> method.
 
-See also the LINE Developers API reference of this method: L<https://developers.line.me/en/reference/messaging-api/#send-push-message>
+See also the LINE Developers API reference of this method: L<https://developers.line.biz/en/reference/messaging-api/#send-push-message>
 
 =head2 multicast([$user_id, ... ], [ $message, ... ])
 
@@ -247,10 +247,10 @@ Send push messages to multiple users.
     $messages->add_text( text => 'Example push text' );
     $bot->multicast([ $user_id ], $messages->build);
 
-You can get a C<user_id> from a L<webhook event object|https://developers.line.me/en/reference/messaging-api/#webhook-event-objects>.
+You can get a C<user_id> from a L<webhook event object|https://developers.line.biz/en/reference/messaging-api/#webhook-event-objects>.
 See the documentation for the C<parse_events_from_json($json)> method.
 
-See also the LINE Developers API reference of this method: L<https://developers.line.me/en/reference/messaging-api/#send-multicast-messages>
+See also the LINE Developers API reference of this method: L<https://developers.line.biz/en/reference/messaging-api/#send-multicast-messages>
 
 =head2 validate_signature($json, $signature)
 
@@ -295,7 +295,7 @@ Bot leaves a room.
 
     $bot->leave_room($room_id);
 
-You can get a C<room_id> by a L<Webhook Event Object|https://developers.line.me/en/reference/messaging-api/#webhook-event-objects>.
+You can get a C<room_id> by a L<Webhook Event Object|https://developers.line.biz/en/reference/messaging-api/#webhook-event-objects>.
 And see also C<parse_events_from_json($json)> method's document.
 
 =head2 leave_group($group_id)
@@ -304,7 +304,7 @@ Bot leaves a group.
 
     $bot->leave_group($group_id);
 
-You can get a C<group_id> from a L<webhook event object|https://developers.line.me/en/reference/messaging-api/#webhook-event-objects>.
+You can get a C<group_id> from a L<webhook event object|https://developers.line.biz/en/reference/messaging-api/#webhook-event-objects>.
 See the documentation for the C<parse_events_from_json($json)> method.
 
 =head2 get_message_content($message_id)
@@ -318,12 +318,12 @@ Get the original file which was sent by user.
         ...
     }
 
-You can get a C<message_id> from a L<webhook event object|https://developers.line.me/en/reference/messaging-api/#webhook-event-objects>.
+You can get a C<message_id> from a L<webhook event object|https://developers.line.biz/en/reference/messaging-api/#webhook-event-objects>.
 See the documentation for the C<parse_events_from_json($json)> method.
 
 You can also see the online API reference documentation.
 
-See also the LINE Developers API reference of this method: L<https://developers.line.me/en/reference/messaging-api/#get-content>
+See also the LINE Developers API reference of this method: L<https://developers.line.biz/en/reference/messaging-api/#get-content>
 
 =head2 get_profile($user_id)
 
@@ -337,7 +337,7 @@ Get user profile information.
         say $ret->status_message;
     }
 
-See also the LINE Developers API reference of this method:  L<https://developers.line.me/en/reference/messaging-api/#get-profile>
+See also the LINE Developers API reference of this method:  L<https://developers.line.biz/en/reference/messaging-api/#get-profile>
 
 =head2 C<< get_number_of_sent_reply_messages($date) >>
 
@@ -384,7 +384,7 @@ Date the messages were sent
 
 =head2 How to build a send message object
 
-See the LINE Developers API reference about L<Message objects|https://developers.line.me/en/reference/messaging-api/#message-objects>
+See the LINE Developers API reference about L<Message objects|https://developers.line.biz/en/reference/messaging-api/#message-objects>
 
 When the C<LINE::Bot::API::Builder::SendMessage> class is used, it is possible easily to build a send message object.
 That class supports a fluent interface.
@@ -587,7 +587,7 @@ You can use a helper module for the template type.
         text  => 'postback message',
     );
     $carousel->add_column($column1->build);
-    
+
     my $column2 = LINE::Bot::API::Builder::TemplateMessage::ImageColumn->new(
         image_url => 'https://example.com/bot/images/item2.jpg',
     )->add_message_action(
@@ -595,7 +595,7 @@ You can use a helper module for the template type.
         text  => 'message',
     );
     $carousel->add_column($column2->build);
-    
+
     my $column3 = LINE::Bot::API::Builder::TemplateMessage::ImageColumn->new(
         image_url => 'https://example.com/bot/images/item3.jpg',
     )->add_uri_action(
@@ -619,6 +619,7 @@ https://opensource.org/licenses/Artistic-2.0
 =head1 SEE ALSO
 
 L<LINE::Bot::API::Event>,
-L<https://business.line.me/>, L<https://developers.line.me/>
+L<https://developers.line.biz/>,
+L<https://at.line.me/>
 
 =cut
